@@ -138,3 +138,38 @@ class UserAuthenticationForm(forms.Form):
 
     def get_user(self):
         return self.user_cache
+
+
+class UserChangePasswordForm(forms.Form):
+    email = forms.EmailField(label=_("Email"), max_length=254, widget=forms.HiddenInput)
+    current_password = forms.CharField(label=_('Current password'), widget=forms.PasswordInput)
+    new_password1 = forms.CharField(label=_('New password1'), widget=forms.PasswordInput)
+    new_password2 = forms.CharField(label=_('New password2'), widget=forms.PasswordInput)
+
+    error_messages = {
+        'invalid_login': _('The password is incorrect'),
+        'password_mismatch': _("The two password fields didn't match."),
+    }
+
+    def clean(self):
+        email = self.cleaned_data.get('email')
+        current_password = self.cleaned_data.get('current_password')
+
+        if email and current_password:
+            self.user_cache = authenticate(email=email, password=current_password)
+
+            if self.user_cache is None:
+                raise forms.ValidationError(
+                    self.error_messages['invalid_login'],
+                    code='invalid_login'
+                )
+
+        return self.cleaned_data
+
+    def clean_new_password2(self):
+        new_password1 = self.cleaned_data.get('new_password1')
+        new_password2 = self.cleaned_data.get('new_password2')
+        if new_password1 and new_password2 and new_password1 != new_password2:
+            raise forms.ValidationError(
+                self.error_messages['password_mismatch'])
+        return new_password2
